# HARD DEPENDENCIES

If you have a Python version lower than Python 2.6 (which already includes
simplejson as the "json" module), you will need to install simplejson from

 - [simplejson](https://github.com/simplejson/simplejson)

# OPTIONAL DEPENDENCIES

If you want to run the UNIT TESTS ("make test"), you also need

 - [Nose](http://readthedocs.org/docs/nose/)
 - [MiniMock](http://pypi.python.org/pypi/MiniMock)
 - [Coverage](http://coverage.readthedocs.io/en/latest/)

If you want to generate the API DOCS ("make docs"), you also need

 - [Epydoc](http://epydoc.sourceforge.net/)

